const imageUrl = "https://camo.githubusercontent.com/065eb10b3c7bbf342ee57290b69c149fa8686775/687474703a2f2f7769726c2e64656c706869626c6f636b732e636f6d2f6173736574732f696d616765732f7769726c2d3330302e706e67";

function loadImage_wrong() {
    const image = document.getElementById('image');
    image.src = imageUrl;
    console.log("image.width: " + image.width);
    console.log("image.height: " + image.height);
}

function loadImage_right() {
    const image = document.getElementById('image');
    image.src = imageUrl;
    image.onload = function () {
        console.log("image.width: " + image.width);
        console.log("image.height: " + image.height);
    }
}

/////////////////////////////////////////////

function loadAsset(url, type, callback) {
    let xhr = new XMLHttpRequest();
    xhr.open('GET', url);
    xhr.responseType = type;
  
    xhr.onload = function() {
        if (callback) {
            callback(xhr.response);
        }
    };
  
    xhr.send();
}

function loadText() {
    loadAsset('config.txt', 'text', function (response) {
        console.log(response);
    });
}

function loadJson() {
    loadAsset('luca.json', 'json', function (response) {
        console.log(response);
    });
}

///////////////////////////////// CALLBACK /////////////////////////////

function loadSequenceAjax() {
    const image = document.getElementById('image');

    loadAsset('config.txt', 'text', function (response) {
        console.log('Persona:', response);
        loadAsset(response, 'json', function (response) {
            console.log('json:', response);
            loadAsset(response.foto, 'blob', function (response) {
                let objectURL = URL.createObjectURL(response);
                image.src = objectURL;
            });
        });
    });
}

///////////////////////////////// PROMISE /////////////////////////////

// Promise + Fetch

// Fetch: va in errore solo in caso di problemi alla rete (controllare .ok)
// Per estrarre il risultato serve una promise
function loadSequencePromise() {
    const image = document.getElementById('image');

    fetch('config.txt')
        .then((response) => {
            return response.text();
        }).then((response) => {
            console.log('Persona:', response);
            return fetch(response);
        }).then((response) => {
            return response.json();
        }).then((response) => {
            console.log('json:', response);
            return fetch(response.foto);
        }).then((response) => {
            return response.blob();
        }).then((response) => {
            let objectURL = URL.createObjectURL(response);
            image.src = objectURL;
        });

}

// Provo a riscrivere la funzione loadAsset usando le promise
function loadAssetP(url, type) {
    return new Promise((resolve, reject) => {
        let xhr = new XMLHttpRequest();
        xhr.open('GET', url);
        xhr.responseType = type;        
      
        xhr.onload = function() {
            if (xhr.status === 200) {
                resolve(xhr.response);
            } else {
                reject(xhr);
            }
        };

        // Network error
        xhr.onerror = function() {
            reject(xhr);
        };
      
        xhr.send();    
    });
}

function loadSequencePromise2() {
    const image = document.getElementById('image');

    loadAssetP('config.txt', 'text')
        .then((response) => {
            console.log(response);
            return loadAssetP(response, 'json');
        }).then((response) => {
            console.log('Persona:', response);
            return loadAssetP(response.foto, 'blob');
        }).then((response) => {
            let objectURL = URL.createObjectURL(response);
            image.src = objectURL;
        }).catch((response) => {
            console.log('Errore: ', response.status);
        });

}

///////////////////////////////// ASYNC / AWAIT /////////////////////////////

async function loadSequenceAsync() {
    const image = document.getElementById('image');

    const personUrl = await loadAssetP('config.txt', 'text');
    const person = await loadAssetP(personUrl, 'json');
    const photoBlob = await loadAssetP(person.foto, 'blob');

    const objectURL = URL.createObjectURL(photoBlob);
    image.src = objectURL;

}

